@@ -29,10 +29,6 @@
 #ifndef _DDD_AsyncAgent_h
 #define _DDD_AsyncAgent_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 /*
     AsyncAgent(app_context, p)
     opens a three-way communication channel to the agent p (see Agent).
@@ -181,13 +177,13 @@ protected:
     void clearHandlers();
 
     // resources
-    XtInputId id(unsigned type)
+    XtInputId id(unsigned type) const
     {
 	assert(type < AsyncAgent_NHandlers);
 	return _ids[type]; 
     }
 
-    AsyncAgentHandler handler(unsigned type)
+    AsyncAgentHandler handler(unsigned type) const
     {
 	assert(type < AsyncAgent_NHandlers);
 	return _handlers[type];
