@@ -29,10 +29,6 @@
 #ifndef _DDD_DataDisp_h
 #define _DDD_DataDisp_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 //-----------------------------------------------------------------------------
 // The `DataDisp' class creates the data display and provides the
 // necessary callback functions.
@@ -167,7 +163,7 @@ class DataDisp {
     //-----------------------------------------------------------------------
     // Create dialogs
     //-----------------------------------------------------------------------
-    static void new_displayCD (Widget w, BoxPoint box_point = BoxPoint());
+    static void new_displayCD (Widget w, const BoxPoint& box_point = BoxPoint());
 
     //-----------------------------------------------------------------------
     // Set sensitivity
@@ -180,7 +176,7 @@ class DataDisp {
 
     static bool lose_selection;
 
-    static void set_args(BoxPoint p = BoxPoint(),
+    static void set_args(const BoxPoint& p = BoxPoint(),
 			 SelectionMode mode = SetSelection);
 
     static void refresh_display_list(bool silent = false);
@@ -203,7 +199,7 @@ class DataDisp {
 				       const string& depends_on,
 				       bool clustered, bool plotted);
 
-    static int getDispNrAtPoint(BoxPoint point);
+    static int getDispNrAtPoint(const BoxPoint& point);
 
     static string numbers(IntArray& a);
     static bool all_data_displays(IntArray& numbers);
@@ -467,7 +463,7 @@ private:
     static void new_user_displayOQC  (const string& answer, void* data);
 
     static void refresh_displayOQC   (const string& answer, void*  data);
-    static void refresh_displayOQAC  (const StringArray& answers,
+    static void refresh_displayOQAC  (StringArray& answers,
 				      const VoidArray& qu_datas,
 				      void*  data);
 
@@ -540,7 +536,7 @@ private:
 					    int& current_frame,
 					    const StringArray& scopes,
 					    DispNode *dn,
-					    bool& ok);
+					    const bool& ok);
 
     static bool get_state(std::ostream& os,
 			  bool restore_state,
@@ -662,6 +658,10 @@ public:
 
     // Restore sane state
     static void make_sane();
+
+private:
+    DataDisp(const DataDisp&);
+    DataDisp& operator=(const DataDisp&);
 };
 
 inline bool DataDisp::get_selection(std::ostream& os, bool include_position)
