@@ -29,11 +29,6 @@
 #ifndef _DDD_GraphNodeI_h
 #define _DDD_GraphNodeI_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
-
 #include "UniqueId.h"
 #include "Box.h"
 #include "bool.h"
@@ -178,7 +173,7 @@ public:
     virtual bool OK() const;
 };
 
-inline std::ostream& operator << (std::ostream& s, GraphNode& node)
+inline std::ostream& operator << (std::ostream& s, const GraphNode& node)
 {
     return s << node.str();
 }
