@@ -29,10 +29,6 @@
 #ifndef _DDD_PosBuffer_h
 #define _DDD_PosBuffer_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 //-----------------------------------------------------------------------------
 // A `PosBuffer' filters position infos from GDB output.
 //-----------------------------------------------------------------------------
@@ -65,13 +61,14 @@ protected:
     void filter_xdb(string& answer);
     void filter_jdb(string& answer);
     void filter_pydb(string& answer);
+    void filter_dbg(string& answer);
     void filter_perl(string& answer);
     void filter_bash(string& answer);
 
     // Filter all lines from ANSWER beginning with current line.  This
     // is required to suppress the line number output after a
     // `stopping in' message.
-    void filter_line(string& answer);
+    void filter_line(string& answer) const;
 
 public:
     bool check_pc;		// Whether to search for PC
