@@ -29,10 +29,6 @@
 #ifndef _DDD_PrintGC_h
 #define _DDD_PrintGC_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "bool.h"
 #include "TypeInfo.h"
 
@@ -42,6 +38,7 @@ struct PrintGC {
 
     virtual bool isFig() const        { return false; }
     virtual bool isPostScript() const { return false; }
+    virtual ~PrintGC() {}
 };
 
 struct FigPrintGC: public PrintGC {
