@@ -29,10 +29,6 @@
 #ifndef _DDD_annotation_h
 #define _DDD_annotation_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "strclass.h"
 #include "GDBAgent.h"
 
