@@ -29,10 +29,6 @@
 #ifndef _DDD_casts_h
 #define _DDD_casts_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "config.h"
 
 #if HAVE_NEW_CASTS
@@ -45,5 +41,20 @@
 #  define REINTERPRET_CAST(TYPE,OBJ) ((TYPE)(OBJ))
 #endif
 
+// Motif does not use "const _XtString" and this leads to many const_cast.
+#define XMST(OBJ) CONST_CAST(char *,OBJ)
+
+// first three fields of XtResource are char*.
+#define XTRESSTR(OBJ) CONST_CAST(char *,OBJ)
+
+// first field of XtActionsRec is char*.
+#define XTARECSTR(OBJ) CONST_CAST(char *,OBJ)
+
+// first two fields of XrmOptionDescRec are char*.
+#define XRMOPTSTR(OBJ) CONST_CAST(char *,OBJ)
+
+// Arg.name is char*.
+#define ARGSTR(OBJ) CONST_CAST(char *,OBJ)
+
 #endif // _DDD_casts_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
