@@ -29,10 +29,6 @@
 #ifndef _DDD_regexps_h
 #define _DDD_regexps_h
 
-#ifdef __GNUG__
-#pragma interface
-#endif
-
 #include "config.h"
 #include "rxclass.h"
 
@@ -169,6 +165,8 @@ extern const regex rxwhite;
 extern const regex rxxdb;
 extern const regex rxxdbpos;
 extern const regex rxdoubleindex;
+extern const regex rxdbgpos;
+extern const regex rxdbgframepos;
 
 #endif // !RUNTIME_REGEX
 
